import { Component, EventEmitter, Input, Output } from '@angular/core';
import { UntypedFormGroup } from '@angular/forms';
import { Employer } from '../../../../models/employer.model';
import { ProfileService } from '../../../../profile/services/profile.service';

@Component({
  selector: 'app-profile-employer-selection',
  templateUrl: './profile-employer-selection.component.html',
})
export class ProfileEmployerSelectionComponent {
  @Input() profileForm: UntypedFormGroup;
  @Output() validateForm = new EventEmitter<Employer>();
  public employers: Employer[];
  public isAlreadySearching = false;

  constructor(private profileService: ProfileService) {}

  public onSearchChange(searchString: string): void {
    this.getEmployers(searchString);
    this.profileForm.get('employer').patchValue({
      name: searchString,
      validated: false,
    });
    this.validateForm.emit();
  }

  public selectedResult(employer: Employer): void {
    this.profileForm.get('employer').patchValue({
      name: employer.name,
      validated: employer.validated,
    });
    this.employers = [];
    this.validateForm.emit();
  }

  private getEmployers(searchString = ''): void {
    if (!this.isAlreadySearching) {
      this.isAlreadySearching = true;
      this.profileService.getEmployers(searchString).subscribe((employers) => {
        this.employers = employers;
        this.isAlreadySearching = false;
      });
    }
  }
}
